pub struct VideoCapture {
termination_recv: Option<Receiver<Terminate>>,
pipewire_state: PipewireState,
}Fields
termination_recv: Option<Receiver<Terminate>>pipewire_state: PipewireStateImplementations
Sourceimpl VideoCapture
impl VideoCapture
pub fn new( pipewire_fd: RawFd, stream_node: u32, ready_state: Arc<ReadyState>, controls: Arc<CaptureControls>, resolution_sender: Sender<Resolution>, frame_tx: Sender<RawVideoFrame>, termination_recv: Receiver<Terminate>, pw_obj: Object, ) -> Result<Self>
fn create_stream(core: CoreRc) -> Result<StreamRc>
fn setup_core_listener(core: &mut CoreRc) -> Result<Listener>
fn setup_stream_listener( stream: &mut StreamRc, data: UserData, ready_state: Arc<ReadyState>, controls: &Arc<CaptureControls>, resolution_sender: Sender<Resolution>, frame_tx: Sender<RawVideoFrame>, ) -> Result<StreamListener<UserData>>
fn connect_stream( stream: &mut StreamRc, stream_node: u32, pw_obj: Object, ) -> Result<()>
Sourcepub fn run(&mut self) -> Result<()>
pub fn run(&mut self) -> Result<()>
Finalizes the pipewire run loop with a terminate receiver and runs it Blocks the current thread so this must be called in a separate thread
fn get_dmabuf_fd(data: &Data) -> Option<RawFd>